@@ -82,11 +82,12 @@ class Daemon(GObject.GObject, TimerManager):
 			WebUI (/rest/errors call)
 				message:	Error message sent by daemon
 		
-		folder-rejected(device_id, folder_id)
+		folder-rejected(device_id, folder_id, label)
 			Emited when daemon detects unexpected folder from known
 			device.
 				device_id:	id of device that send unexpected folder id
 				folder_id:	id of unexpected folder
+				label:		label of unexpected folder or None
 		
 		device-rejected(device_id, device_name, address)
 			Emited when daemon detects connection from unknown device
@@ -219,14 +220,14 @@ class Daemon(GObject.GObject, TimerManager):
 		startup-complete():
 			Emited when daemon initialization is complete.
 		
-		system-data-updated (ram_ussage, cpu_ussage, announce)
+		system-data-updated (ram_ussage, cpu_ussage, d_failed, d_total)
 			Emited every time when system informations are recieved
 			from daemon.
 				ram_ussage:	memory ussage in bytes
 				cpu_ussage:	CPU ussage in percent (0.0 to 100.0)
-				announce:	Dict with list of { announce_server : value }
-							or None if announce is disabled
-							Value is True if daemon is connected to server
+				d_failed:	Number of discovery servers that daemon failed to
+							connect to
+				d_total:	Total number of discovery servers
 	"""
 	
 	
@@ -238,7 +239,7 @@ class Daemon(GObject.GObject, TimerManager):
 			b"config-loaded"		: (GObject.SIGNAL_RUN_FIRST, None, (object,)),
 			b"connection-error"		: (GObject.SIGNAL_RUN_FIRST, None, (int, object, object)),
 			b"error"				: (GObject.SIGNAL_RUN_FIRST, None, (object,)),
-			b"folder-rejected"		: (GObject.SIGNAL_RUN_FIRST, None, (object,object)),
+			b"folder-rejected"		: (GObject.SIGNAL_RUN_FIRST, None, (object,object,object)),
 			b"device-rejected"		: (GObject.SIGNAL_RUN_FIRST, None, (object,object,object)),
 			b"my-id-changed"		: (GObject.SIGNAL_RUN_FIRST, None, (object,)),
 			b"device-added"			: (GObject.SIGNAL_RUN_FIRST, None, (object, object, bool, object)),
@@ -266,7 +267,7 @@ class Daemon(GObject.GObject, TimerManager):
 			b"item-started"			: (GObject.SIGNAL_RUN_FIRST, None, (object,object,object)),
 			b"item-updated"			: (GObject.SIGNAL_RUN_FIRST, None, (object,object,object)),
 			b"startup-complete"		: (GObject.SIGNAL_RUN_FIRST, None, ()),
-			b"system-data-updated"	: (GObject.SIGNAL_RUN_FIRST, None, (int, float, object)),
+			b"system-data-updated"	: (GObject.SIGNAL_RUN_FIRST, None, (int, float, int, int)),
 		}
 	
 	# Constants for 'reason' parameter of disconnected event
@@ -281,7 +282,7 @@ class Daemon(GObject.GObject, TimerManager):
 	TLS_UNSUPPORTED	= 4
 	UNKNOWN			= 255
 	
-	def __init__(self):
+	def __init__(self, syncthing_configxml=None):
 		GObject.GObject.__init__(self)
 		TimerManager.__init__(self)
 		self._CSRFtoken = None
@@ -289,6 +290,7 @@ class Daemon(GObject.GObject, TimerManager):
 		self._api_key = None
 		self._connected = False
 		self._refresh_interval = 1 # seconds
+		self._configxml = syncthing_configxml
 		# syncing_folders holds set of folders that are being synchronized
 		self._syncing_folders = set()
 		# stopped_folders holds set of folders in 'stopped' state
@@ -322,9 +324,11 @@ class Daemon(GObject.GObject, TimerManager):
 	
 	def _read_config(self):
 		# Read syncthing config to get connection url
-		configxml = os.path.join(get_config_dir(), "syncthing", "config.xml")
+		if not self._configxml:
+			self._configxml = os.path.join(get_config_dir(), "syncthing", "config.xml")
 		try:
-			config = file(configxml, "r").read()
+			log.debug("Reasing syncthing config %s", self._configxml)
+			config = file(self._configxml, "r").read()
 		except Exception, e:
 			raise InvalidConfigurationException("Failed to read daemon configuration: %s" % e)
 		try:
@@ -923,9 +927,11 @@ class Daemon(GObject.GObject, TimerManager):
 			else:
 				self._rest_request("system/version", self._syncthing_cb_version)
 		
+		d_failed, d_total = 0, 0
 		announce = None
-		if "extAnnounceOK" in data:
-			announce = data["extAnnounceOK"]
+		if "discoveryEnabled" in data and data["discoveryEnabled"]:
+			d_total = data["discoveryMethods"]
+			d_failed = len(data["discoveryErrors"])
 		
 		if "startTime" in data:
 			if self._instance_id is None:
@@ -940,9 +946,8 @@ class Daemon(GObject.GObject, TimerManager):
 					self.cancel_all()
 					return
 		
-		self.emit('system-data-updated',
-			data["sys"], float(data["cpuPercent"]),
-			announce)
+		self.emit('system-data-updated', data["sys"],
+			float(data["cpuPercent"]), d_failed, d_total)
 		
 		self.timer("system", self._refresh_interval * 5, self._rest_request, "system/status", self._syncthing_cb_system)
 	
@@ -1113,9 +1118,11 @@ class Daemon(GObject.GObject, TimerManager):
 			self.emit("device-resumed", nid)
 			self._request_last_seen()
 		elif eType == "FolderRejected":
+			print e["data"]
 			nid = e["data"]["device"]
 			rid = e["data"]["folder"]
-			self.emit("folder-rejected", nid, rid)
+			label = e["data"]["folderLabel"] if "folderLabel" in e["data"] else None
+			self.emit("folder-rejected", nid, rid, label)
 		elif eType == "DeviceRejected":
 			nid = e["data"]["device"]
 			name = e["data"]["name"]
@@ -1340,7 +1347,7 @@ class Daemon(GObject.GObject, TimerManager):
 	def override(self, folder_id):
 		""" Asks daemon to override changes made in specified folder """
 		id_enc = urllib.quote(folder_id.encode('utf-8'))
-		self._rest_post("model/override?folder=%s" % (id_enc,), {}, lambda *a: a, lambda *a: log.error(a), folder_id)
+		self._rest_post("db/override?folder=%s" % (id_enc,), {}, lambda *a: a, lambda *a: log.error(a), folder_id)
 	
 	def request_events(self):
 		"""
